@@ -4,9 +4,8 @@ from django.conf import settings
 CURRENCIES = getattr(settings, 'ZIPFELCHAPPE_CURRENCIES',
     ('CHF', 'EUR', 'USD'))
 
-BACKER_MODEL = getattr(settings, 'ZIPFELCHAPPE_BACKER_MODEL',
-    'zipfelchappe.Backer')
-
 DISQUS_SHORTNAME = getattr(settings, 'ZIPFELCHAPPE_DISQUS_SHORTNAME', None)
 
+PAGINATE_BY = getattr(settings, 'ZIPFELCHAPPE_PAGINATE_BY', 10)
+
 ALLOW_ANONYMOUS_PLEDGES = getattr(settings, 'ZIPFECHAPPE_ALLOW_ANONYMOUS_PLEDGES', True)
