@@ -16,10 +16,9 @@ from feincms.management.checker import check_database_schema as check_db_schema
 from feincms.utils.queryset_transform import TransformQuerySet
 from feincms.content.application import models as app_models
 
-from .app_settings import BACKER_MODEL, CURRENCIES
+from .app_settings import CURRENCIES
 from .base import CreateUpdateModel
 from .fields import CurrencyField
-from .utils import use_default_backer_model
 
 CURRENCY_CHOICES = list(((cur, cur) for cur in CURRENCIES))
 
@@ -43,7 +42,7 @@ class TranslatedMixin(object):
             return self._translation
 
 
-class BackerBase(models.Model):
+class Backer(models.Model):
 
     user = models.ForeignKey(User, blank=True, null=True, unique=True)
 
@@ -56,22 +55,30 @@ class BackerBase(models.Model):
     class Meta:
         verbose_name = _('backer')
         verbose_name_plural = _('backers')
-        abstract = True
 
     def __unicode__(self):
         return self.full_name
 
     @property
     def first_name(self):
-        return self.user.first_name if self.user else self._first_name
+        if self.user and self.user.first_name:
+            return self.user.first_name
+        else:
+            return self._first_name
 
     @property
     def last_name(self):
-        return self.user.last_name if self.user else self._last_name
+        if self.user and self.user.last_name:
+            return self.user.last_name
+        else:
+            return self._last_name
 
     @property
     def email(self):
-        return self.user.email if self.user else self._email
+        if self.user and self.user.email:
+            return self.user.email
+        else:
+            return self._email
 
     @property
     def full_name(self):
@@ -80,10 +87,6 @@ class BackerBase(models.Model):
         else:
             return unicode(self.user)
 
-if use_default_backer_model():
-    class Backer(BackerBase):
-        pass
-
 
 class Pledge(CreateUpdateModel, TranslatedMixin):
 
@@ -97,7 +100,7 @@ class Pledge(CreateUpdateModel, TranslatedMixin):
         (PAID, _('Paid')),
     )
 
-    backer = models.ForeignKey(BACKER_MODEL, verbose_name=_('backer'),
+    backer = models.ForeignKey('Backer', verbose_name=_('backer'),
         related_name='pledges', blank=True, null=True)
 
     project = models.ForeignKey('Project', verbose_name=_('project'),
@@ -117,6 +120,8 @@ class Pledge(CreateUpdateModel, TranslatedMixin):
     status = models.PositiveIntegerField(_('status'), choices=STATUS_CHOICES,
             default=UNAUTHORIZED)
 
+    manually = models.BooleanField(_('inserted manually'))
+
     class Meta:
         verbose_name = _('pledge')
         verbose_name_plural = _('pledges')
@@ -322,7 +327,7 @@ class Project(Base, TranslatedMixin):
     end = models.DateTimeField(_('end'),
         help_text=_('Until when money is raised'))
 
-    backers = models.ManyToManyField(BACKER_MODEL, verbose_name=_('backers'),
+    backers = models.ManyToManyField('Backer', verbose_name=_('backers'),
         through='Pledge')
 
     def teaser_img_upload_to(instance, filename):
@@ -446,11 +451,6 @@ class Project(Base, TranslatedMixin):
             anonymously=False
         )
 
-    @classmethod
-    def register_extension(cls, register_fn):
-        register_fn(cls, ProjectAdmin)
-
-
 # Zipfelchappe has two fixed regions which cannot be configured a.t.m.
 # This may change in future versions but suffices our needs for now
 Project.register_regions(
@@ -459,4 +459,3 @@ Project.register_regions(
 )
 
 signals.post_syncdb.connect(check_db_schema(Project, __name__), weak=False)
-
