@@ -9,7 +9,7 @@ from django.contrib import messages
 from django.contrib.auth import login, authenticate
 from django.contrib.auth.forms import AuthenticationForm
 from django.contrib.admin.views.decorators import staff_member_required
-from django.core.urlresolvers import reverse, NoReverseMatch
+from django.core.urlresolvers import NoReverseMatch
 from django.utils.translation import ugettext_lazy as _
 from django.views.decorators.csrf import csrf_exempt
 
@@ -18,8 +18,8 @@ from feincms.module.mixins import ContentView
 
 from . import forms, app_settings
 from .emails import send_pledge_completed_message
-from .models import Project, Pledge, Category, Update, MailTemplate
-from .utils import get_backer_model, use_default_backer_model, get_object_or_none
+from .models import Project, Pledge, Backer, Category, Update, MailTemplate
+from .utils import get_object_or_none
 
 
 #-----------------------------------
@@ -114,8 +114,8 @@ def redirect(view_name, *args, **kwargs):
 #-----------------------------------
 
 class ProjectListView(FeincmsRenderMixin, ListView):
-
     context_object_name = "project_list"
+    paginate_by = app_settings.PAGINATE_BY
     model = Project
 
     def get_queryset(self):
@@ -130,6 +130,7 @@ class ProjectListView(FeincmsRenderMixin, ListView):
 
 class ProjectCategoryListView(FeincmsRenderMixin, ListView):
     context_object_name = "project_list"
+    paginate_by = app_settings.PAGINATE_BY
     model = Project
 
     def get_queryset(self):
@@ -218,24 +219,15 @@ def project_back_form(request, slug):
 @feincms_render
 @requires_pledge
 def backer_authenticate(request, pledge):
-    BackerModel = get_backer_model()
 
     if pledge.backer is not None:
         return redirect('zipfelchappe_payment')
 
     if request.user.is_authenticated():
-        try:
-            backer = BackerModel.objects.get(user=request.user)
-            pledge.backer = backer
-            pledge.save()
-            return redirect('zipfelchappe_payment')
-        except BackerModel.DoesNotExist:
-            if use_default_backer_model():
-                pledge.backer = BackerModel.objects.create(user=request.user)
-                pledge.save()
-                return redirect('zipfelchappe_payment')
-            else:
-                return redirect('zipfelchappe_backer_profile')
+        backer, created = Backer.objects.get_or_create(user=request.user)
+        pledge.backer = backer
+        pledge.save()
+        return redirect('zipfelchappe_payment')
     else:
         return ('zipfelchappe/backer_authenticate_form.html', {
             'pledge': pledge,
@@ -243,26 +235,9 @@ def backer_authenticate(request, pledge):
             'login_form': AuthenticationForm(),
             'register_user_form': forms.RegisterUserForm(),
             'register_backer_form': forms.RegisterBackerForm(),
-            'userless_form': forms.UserlessBackerForm()
         })
 
 
-@requires_pledge_cbv
-class BackerProfileView(FeincmsRenderMixin, PledgeContextMixin, FormView):
-    form_class = forms.AuthenticatedBackerForm
-    template_name = "zipfelchappe/backer_profile_form.html"
-
-    def get_success_url(self):
-        return app_reverse('zipfelchappe_backer_authenticate',
-                           'zipfelchappe.urls')
-
-    def form_valid(self, form):
-        backer = form.save(commit=False)
-        backer.user = self.request.user
-        backer.save()
-        return super(BackerProfileView, self).form_valid(form)
-
-
 @requires_pledge_cbv
 class BackerLoginView(FeincmsRenderMixin, PledgeContextMixin, FormView):
     form_class = AuthenticationForm
@@ -315,21 +290,6 @@ def backer_register(request, pledge):
     })
 
 
-@requires_pledge_cbv
-class UserlessBackerView(FeincmsRenderMixin, PledgeContextMixin, FormView):
-    form_class = forms.UserlessBackerForm
-    template_name = "zipfelchappe/backer_userless_form.html"
-
-    def get_success_url(self):
-        return reverse('zipfelchappe_payment')
-
-    def form_valid(self, form):
-        backer = form.save()
-        self.pledge.backer = backer
-        self.pledge.save()
-        return super(UserlessBackerView, self).form_valid(form)
-
-
 def pledge_thankyou(request):
     pledge = get_session_pledge(request)
 
@@ -372,8 +332,6 @@ def send_test_mail(request):
     template = request.POST.get('template', None)
     recipient = request.POST.get('recipient', None)
 
-    BackerModel = get_backer_model()
-
     mail_template = MailTemplate(
         project=project,
         action=action,
@@ -384,7 +342,7 @@ def send_test_mail(request):
     fake_plede = Pledge(
         project=project,
         amount=10,
-        backer=BackerModel(
+        backer=Backer(
             _first_name=request.user.first_name,
             _last_name=request.user.last_name,
             _email=recipient
